@@ -1,5 +1,8 @@
 package App::lcpan::Cmd::inject;
 
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '1.006'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
@@ -7,11 +10,6 @@ use warnings;
 require App::lcpan;
 use Proc::ChildError qw(explain_child_error);
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-05-07'; # DATE
-our $DIST = 'App-lcpan'; # DIST
-our $VERSION = '1.070_001'; # TRIAL VERSION
-
 our %SPEC;
 
 $SPEC{'handle_cmd'} = {
@@ -30,7 +28,7 @@ $SPEC{'handle_cmd'} = {
             'x.name.is_plural' => 1,
             req => 1,
             pos => 0,
-            slurpy => 1,
+            greedy => 1,
         },
     },
     deps => {
@@ -73,16 +71,12 @@ App::lcpan::Cmd::inject - Inject one or more tarballs to the mirror
 
 =head1 VERSION
 
-This document describes version 1.070_001 of App::lcpan::Cmd::inject (from Perl distribution App-lcpan), released on 2022-05-07.
+This document describes version 1.006 of App::lcpan::Cmd::inject (from Perl distribution App-lcpan), released on 2016-09-25.
 
 =head1 FUNCTIONS
 
 
-=head2 handle_cmd
-
-Usage:
-
- handle_cmd(%args) -> [$status_code, $reason, $payload, \%result_meta]
+=head2 handle_cmd(%args) -> [status, msg, result, meta]
 
 Inject one or more tarballs to the mirror.
 
@@ -96,7 +90,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cpan> => I<dirname>
 
-Location of your local CPAN mirror, e.g. E<sol>pathE<sol>toE<sol>cpan.
+Location of your local CPAN mirror, e.g. /path/to/cpan.
 
 Defaults to C<~/cpan>.
 
@@ -106,29 +100,16 @@ Defaults to C<~/cpan>.
 
 Filename of index.
 
-If C<index_name> is a filename without any path, e.g. C<index.db> then index will
-be located in the top-level of C<cpan>. If C<index_name> contains a path, e.g.
-C<./index.db> or C</home/ujang/lcpan.db> then the index will be located solely
-using the C<index_name>.
-
-=item * B<use_bootstrap> => I<bool> (default: 1)
-
-Whether to use bootstrap database from App-lcpan-Bootstrap.
-
-If you are indexing your private CPAN-like repository, you want to turn this
-off.
-
-
 =back
 
 Returns an enveloped result (an array).
 
-First element ($status_code) is an integer containing HTTP-like status code
+First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-($reason) is a string containing error message, or something like "OK" if status is
-200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
-element (%result_meta) is called result metadata and is optional, a hash
-that contains extra information, much like how HTTP response headers provide additional metadata.
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
 Return value:  (any)
 
@@ -140,34 +121,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan>
 
 Source repository is at L<https://github.com/perlancar/perl-App-lcpan>.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 CONTRIBUTING
-
-
-To contribute, you can send patches by email/via RT, or send pull requests on
-GitHub.
-
-Most of the time, you don't need to build the distribution yourself. You can
-simply modify the code, then test via:
-
- % prove -l
-
-If you want to build the distribution (e.g. to try to install it locally on your
-system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan>
@@ -176,4 +129,15 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by perlancar@cpan.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
